# Usage

To install:


```sh
conda create -c conda-forge jupyterlab
pip install metadsl_core metadsl metadsl_visualize
jupyter labextension install typez
```


Then, if you are exploring expressions in a notebook import `typez_visualize` to get interactive graphs.
